@@ -24,12 +24,14 @@ def sign_in(auth, request, session, *args, **kwargs):
     if auth.wsgi.is_post(request) and auth.csrf_token_is_valid(request):
         if auth.session_key in session:
             del session[auth.session_key]
+
         user = auth.authenticate(credentials)
         if user and not user.deleted:
             user.last_sign_in = datetime.utcnow()
-            auth.db.session.commit()
             remember = bool(credentials.get('remember', True))
             auth.login(user, remember=remember)
+            auth.db.session.commit()
+
             next = pop_next_url(auth, request, session)
             return auth.wsgi.redirect(next)
 
@@ -45,6 +47,7 @@ def sign_in(auth, request, session, *args, **kwargs):
 def sign_out(auth, request, *args, **kwargs):
     # the logout action itself must be CSRF protected,
     # but the view could be called twice by mistake
+    # so we ignore the second one instead of raising an error
     if auth.csrf_token_is_valid(request):
         auth.logout()
 
@@ -73,14 +76,11 @@ def reset_password(auth, request, token=None, *args, **kwargs):
         if user:
             auth.login(user)
             return change_password(auth, request, manual=False, **kwargs)
-        kwargs['error'] = True
+        kwargs['error'] = 'WRONG TOKEN'
 
     elif auth.wsgi.is_post(request) and auth.csrf_token_is_valid(request):
         login = auth.wsgi.get_from_params(request, 'login') or ''
         user = auth.User.by_login(login)
-        # If the login provided does not exist in the system
-        # or the user is inactive, no error is raised
-        # (but an email is not sent)
         if user:
             reset_url = auth.wsgi.make_full_url(
                 request,
@@ -94,7 +94,9 @@ def reset_password(auth, request, token=None, *args, **kwargs):
                 'expire_after': auth.token_life,
             }
             _email_token(auth, user, data)
-        kwargs['ok'] = True
+            kwargs['ok'] = True
+        else:
+            kwargs['error'] = 'WRONG USER'
 
     kwargs['auth'] = auth
     kwargs['credentials'] = credentials
